##Packages required
library(ggplot2)
library(ggsignif)
library(ggpubr)

rm(list=ls())	

setwd("") ###set directory where csv files saved

level_order <- c('Hadeda', 'Sacred', 'Glossy')
my_comparisons <- list( c("Hadeda", "Sacred"), c("Hadeda", "Glossy"), c("Sacred", "Glossy") )

windows()

#####Fig S2
admass2carla<-read.csv("dorsal width.csv", header=T)
admass.pred<-read.csv("dorsal width ave.csv", header=T)

DWR<-ggplot(admass2carla, aes(x=factor(Species, level = level_order), y=Ratio)) + 
  geom_jitter(position=position_jitter(0.2), cex=3.5, alpha = 0.3)+
  geom_point(aes(x=spp, y=Ratio,color=spp), data=admass.pred, cex=6)+
  geom_errorbar(aes(x=spp, ymin=minse, ymax=maxse,color=spp), width = 0.1, size=1,data=admass.pred)+
  xlab("Species") + ylab("Dorsal beak width ratio")+
  stat_compare_means(aes(label=paste0("p =", ..p.format..)),label.y = 0.45,size=7.5)+
  stat_compare_means(comparisons = my_comparisons, method= "wilcox.test", label = "p.signif", size=7)+
  scale_color_manual(values = c("#4E84C4", "#D16103", "#52854C"))

DWR+theme_classic()+ theme(
  axis.title.x = element_text(size=20),
  axis.title.y = element_text(size=20))+ 
  theme(axis.text.x = element_text(color="black", 
                                   size=15),
        axis.text.y = element_text(color="black", 
                                   size=15))+
  theme(legend.position = "none")


###Fig4A

admass3carla<-read.csv("lateral width.csv", header=T)
admass.pred2<-read.csv("lateral width ave.csv", header=T)

LWR<-ggplot(admass3carla, aes(x=factor(Species, level = level_order), y=Ratio)) + 
  geom_jitter(position=position_jitter(0.2), cex=3.5, alpha = 0.3)+
  geom_point(aes(x=spp, y=Ratio,color=spp), data=admass.pred2, cex=6)+
  geom_errorbar(aes(x=spp, ymin=minse, ymax=maxse,color=spp), width = 0.1, size=1,data=admass.pred2)+
  xlab("Species") + ylab("Lateral beak depth ratio")+
  scale_color_manual(values = c("#4E84C4", "#D16103", "#52854C"))+
  stat_compare_means(aes(label=paste0("p =", ..p.format..)),label.y = 0.45,size=7.5)+
  stat_compare_means(comparisons = my_comparisons, method= "wilcox.test", label = "p.signif", size=7)

LWR+theme_classic()+ theme(
    axis.title.x = element_text(size=20),
    axis.title.y = element_text(size=20))+ 
  theme(axis.text.x = element_text(color="black", 
                                   size=15),
        axis.text.y = element_text(color="black", 
                                   size=15))+
  theme(legend.position = "none")



######Fig 4B

admass2carla<-read.csv("pitting.csv", header=T)
admass.pred<-read.csv("no2.csv", header=T)

ggplot(admass2carla, aes(x=factor(Species, level = level_order), y=Number)) + 
  geom_jitter(position=position_jitter(0.2), cex=3.5, alpha = 0.3)+
  geom_point(aes(x=spp, y=Number,color=spp), data=admass.pred, cex=6)+
  geom_errorbar(aes(x=spp, ymin=minse, ymax=maxse,color=spp), width = 0.1, size=1,data=admass.pred)+
  xlab("Species") + ylab("Number of pits")+
  stat_compare_means(aes(label=paste0("p =", ..p.format..)),label.y = 7300,size=7.5)+
  stat_compare_means(comparisons = my_comparisons, method= "wilcox.test", label = "p.signif",size=7)+
  scale_color_manual(values = c("#4E84C4", "#D16103", "#52854C"))+
theme_classic()+ theme(
  axis.title.x = element_text(size=20),
  axis.title.y = element_text(size=20))+ 
  theme(axis.text.x = element_text(color="black", 
                                   size=15),
        axis.text.y = element_text(color="black", 
                                   size=15))+
  theme(legend.position = "none")



###Fig 4C

admass.pred2<-read.csv("ratiopit.csv", header=T)

ggplot(admass2carla, aes(x=factor(Species, level = level_order), y=Ratio.pitted)) + 
  geom_jitter(position=position_jitter(0.2), cex=3.5, alpha = 0.3)+
  geom_point(aes(x=spp, y=Ratio.pitted,color=spp), data=admass.pred2, cex=6)+
  geom_errorbar(aes(x=spp, ymin=minse, ymax=maxse,color=spp), width = 0.1, size=1,data=admass.pred2)+
  xlab("Species") + ylab("Extent of pitting (% beak length)")+
  stat_compare_means(aes(label=paste0("p =", ..p.format..)),label.y = 70,size=7.5)+
  stat_compare_means(comparisons = my_comparisons, method= "wilcox.test", label = "p.signif",size=7)+
  scale_color_manual(values = c("#4E84C4", "#D16103", "#52854C"))+
  theme_classic()+ theme(
    axis.title.x = element_text(size=20),
    axis.title.y = element_text(size=20))+ 
  theme(axis.text.x = element_text(color="black", 
                                   size=15),
        axis.text.y = element_text(color="black", 
                                   size=15))+
  theme(legend.position = "none")


###Fig 4E

admass.pred3<-read.csv("pits per bto.csv", header=T)

ggplot(admass2carla, aes(x=factor(Species, level = level_order), y=Pits.per.BTO.length)) + 
  geom_jitter(position=position_jitter(0.2), cex=3.5, alpha = 0.3)+
  geom_point(aes(x=spp, y=Pits.per.BTO.length,color=spp), data=admass.pred3, cex=6)+
  geom_errorbar(aes(x=spp, ymin=minse, ymax=maxse,color=spp), width = 0.1, size=1,data=admass.pred3)+
  xlab("Species") + ylab("Pit density (pits/mm)")+
  stat_compare_means(aes(label=paste0("p =", ..p.format..)),label.y = 100,size=7.5)+
  stat_compare_means(comparisons = my_comparisons, method= "wilcox.test", label = "p.signif", size=7)+
  scale_color_manual(values = c("#4E84C4", "#D16103", "#52854C"))+
  theme_classic()+ theme(
    axis.title.x = element_text(size=20),
    axis.title.y = element_text(size=20))+ 
  theme(axis.text.x = element_text(color="black", 
                                   size=15),
        axis.text.y = element_text(color="black", 
                                   size=15))+
  theme(legend.position = "none")

####Fig 4F

dat<-read.csv("hcpits.csv", header=T)
dat2<-read.csv("hcstats.csv", header=T)
dat3<-read.csv("no2.csv", header=T)
attach(dat)

ggplot(dat,aes(x=Pits, y=HC.pit, color=Species)) +
  geom_point(cex=6)+
  geom_errorbar(aes(x=Pits, ymin=minse, ymax=maxse), width=100,data=dat2)+
  geom_errorbarh(aes(y=HC, xmin=minse, xmax=maxse,color=spp),data=dat3)+
  xlab("Number of Pits") + ylab("Herbst Corpuscles per pit")+
  scale_color_manual(values = c("#4E84C4", "#D16103", "#52854C"))+
  theme_classic()+ theme(
    axis.title.x = element_text(size=20),
    axis.title.y = element_text(size=20))+ 
  theme(axis.text.x = element_text(color="black", 
                                   size=15),
        axis.text.y = element_text(color="black", 
                                   size=15))+
  theme(legend.position = "none")
  

#####Fig 4D
dat1<-read.csv("pitting.csv", header=T)

ggplot(dat1, aes(x=Ratio.pitted, y=Number)) + 
  geom_point(aes(x=Ratio.pitted, y=Number, color=Species), data=dat1, cex=6) +
  geom_smooth(method=lm, color="black", size=0.8, alpha=0.3) +
  scale_color_manual(values = c("#4E84C4", "#D16103", "#52854C")) +
  xlab("Extent of pitting (% beak length)") + ylab("Number of pits") +
  geom_text(x=30, y=5500, label="R=0.83",size=7.5) +
  geom_text(x=30, y=5000, label="p=0.0004",size=7.5)+
  theme_classic()+ theme(
    axis.title.x = element_text(size=20),
    axis.title.y = element_text(size=20))+ 
  theme(axis.text.x = element_text(color="black", 
                                   size=15),
        axis.text.y = element_text(color="black", 
                                   size=15))+
  theme(legend.position = "none")

detach(dat)

######